CREATE FUNCTION [dbo].[UTCConvert] (
	@date datetime,
	@zonename nvarchar(100),
	@toUtc int = 1
) 
RETURNS datetime
AS
BEGIN
	IF @date is null
		RETURN NULL
	
	  -- litmit of DATEDIFF in MS SQL. Refer to https://msdn.microsoft.com/en-us/library/ms189794.aspx and http://www.epochconverter.com/
	  -- exceed these time then an overflow exception will be thrown when using DATEDIFF()
	  Declare @minEpoch datetime = '1901-12-14'
	  Declare @maxEpoch datetime = '2038-01-19'
	  
	  IF @date > @maxEpoch or @date < @minEpoch
	  BEGIN
		return @date
	  END

	Declare @offset bigint
	Declare @timeStamp bigint	
	Select @timeStamp = DATEDIFF(SECOND,{d '1970-01-01'}, @date)
		
	DECLARE @topCount INT
	SET @topCount = 1
	select TOP(@topCount) @offset = gmt_offset -- Because data of Timezone already orderd by time_start
	from dbo.GetZone_Inline(@zonename) 
	where time_start <= @timeStamp
	
	IF (@offset IS NULL) -- For @date before 2000-01-01 in some zones
		select @offset = MIN(gmt_offset) from dbo.GetZone_Inline(@zonename) 
	
	IF (@offset IS NULL) -- For @date is UTC
		select @offset = 0
	
	IF (@toUtc = 0) -- Convert from UTC ==> Local
		RETURN DATEADD(SECOND, @offset, @date)

	-- Convert from Local ==> UTC
	RETURN DATEADD(SECOND, -@offset, @date)
END