CREATE PROCEDURE  dbo.UTCConversion_Run
(@Debug INT = NULL)
AS
BEGIN
	DECLARE @id int
	DECLARE @SQL nvarchar(4000)
	DECLARE @StartTime DATETIME
	DECLARE @EndTime DATETIME
	
	IF NOT Object_ID('tempdb..#convert_sql') IS NULL DROP TABLE #convert_sql

	SELECT [id], [sql], [converted] 
	INTO #convert_sql
	FROM [UTCConversionQuery] WHERE [sql] is not null
		
	BEGIN TRY
		WHILE EXISTS(SELECT [id] FROM #convert_sql WHERE [converted] IS NULL OR [converted] = 0)
		BEGIN
			SELECT TOP 1 @id = [id], @SQL = [sql] FROM #convert_sql WHERE [converted] IS NULL OR [converted] = 0
			
			BEGIN TRAN
				-- Exec sql query
				SET @StartTime = GETUTCDATE()
				EXEC sp_executesql @SQL
				SET @EndTime = GETUTCDATE()
				UPDATE dbo.[UTCConversionQuery] SET [converted] = 1, [time_start] = @StartTime, [time_end] = @EndTime, [error_msg] = '' WHERE [id] = @id	
			COMMIT

			DELETE #convert_sql WHERE id = @id
		END		
	END TRY

	BEGIN CATCH
		DECLARE @ErrorMessage NVARCHAR(4000);
		DECLARE @ErrorSeverity INT;
		DECLARE @ErrorState INT;

		SELECT @ErrorMessage = ERROR_MESSAGE(), @ErrorSeverity = ERROR_SEVERITY(), @ErrorState = ERROR_STATE();
		IF @Debug IS NOT NULL PRINT 'ROLLBACK: ' + @ErrorMessage

		ROLLBACK

		UPDATE [UTCConversionQuery] SET [error_msg] = @ErrorMessage, [time_start] = @StartTime WHERE [id] = @id
		RAISERROR (@ErrorMessage, @ErrorSeverity, @ErrorState)
	END CATCH

	
	IF NOT Object_ID('tempdb..#convert_sql') IS NULL DROP TABLE #convert_sql
END
